# HostBundleClientConfig

The Client configuration associated with a list of hosts and their associated destinations. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bundle** | [**HostBundle**](HostBundle.md) |  | [optional] 
**configuration_format** | **str** | The hosts file configuration format. Permitted values:    etc_hosts  | [optional] 
**configuration_file** | **str** | The base64-encoded contents of the configuration file.  | [optional] [readonly] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


